@@ -7,7 +7,7 @@ use strict;
 
 package XML::Compile::SOAP::Client;
 use vars '$VERSION';
-$VERSION = '3.07';
+$VERSION = '3.08';
 
 
 use Log::Report 'xml-compile-soap', syntax => 'SHORT';
@@ -44,7 +44,7 @@ sub compileClient(@)
 
     if(ref $transport eq 'CODE') { ; }
     elsif(UNIVERSAL::isa($transport, 'XML::Compile::Transport::SOAPHTTP'))
-    {   $transport = $transport->compileClient;
+    {   $transport = $transport->compileClient(soap => $args{soap});
     }
     else
     {   error __x"transport for client {name} is code ref or {type} object, not {is}"
